@@ -64,10 +64,12 @@ setClassUnion("functionOrNULL", c("NULL", "function"))
 setClassUnion("listOrNULL", c("NULL", "list"))
 ## TODO (?) make "list" more specific, e.g FormatList, or FunctionList?
 setClassUnion("FormatSpec", c("NULL", "character", "function", "list"))
+setClassUnion("ExprOrNULL", c("NULL", "expression"))
 
 setClass("ValueWrapper", representation(
   value = "ANY",
-  label = "characterOrNULL"
+  label = "characterOrNULL",
+  subset_expression = "ExprOrNULL"
 ),
 contains = "VIRTUAL"
 )
@@ -80,7 +82,7 @@ setClass("SplitValue",
   representation(extra = "list")
 )
 
-SplitValue <- function(val, extr = list(), label = val) {
+SplitValue <- function(val, extr = list(), label = val, sub_expr = NULL) {
   if (is(val, "SplitValue")) {
     if (length(splv_extra(val)) > 0) {
       extr <- c(splv_extra(val), extr)
@@ -94,10 +96,16 @@ SplitValue <- function(val, extr = list(), label = val) {
   if (!is(label, "character")) {
     label <- as.character(label)
   }
+
+  if (!is.null(sub_expr) && !is.expression(sub_expr)) {
+    sub_expr <- as.expression(sub_expr)
+  } ## sometimes they will be "call" objects, etc
   check_ok_label(label)
   new("SplitValue",
     value = val,
-    extra = extr, label = label
+    extra = extr,
+    label = label,
+    subset_expression = sub_expr
   )
 }
 
@@ -107,13 +115,14 @@ setClass("LevelComboSplitValue",
 )
 
 ## wrapped in user-facing `add_combo_facet`
-LevelComboSplitValue <- function(val, extr, combolevels, label = val) {
+LevelComboSplitValue <- function(val, extr, combolevels, label = val, sub_expr = NULL) {
   check_ok_label(label)
   new("LevelComboSplitValue",
     value = val,
     extra = extr,
     combolevels = combolevels,
-    label = label
+    label = label,
+    subset_expression = sub_expr
   )
 }
 
@@ -139,7 +148,9 @@ setClass("Split",
     content_indent_modifier = "integer",
     content_extra_args = "list",
     page_title_prefix = "character",
-    child_section_div = "character"
+    child_section_div = "character",
+    child_show_colcounts = "logical",
+    child_colcount_format = "FormatSpec"
   )
 )
 
@@ -185,7 +196,9 @@ VarLevelSplit <- function(var,
                           cvar = "",
                           cextra_args = list(),
                           page_prefix = NA_character_,
-                          section_div = NA_character_) {
+                          section_div = NA_character_,
+                          show_colcounts = FALSE,
+                          colcount_format = NULL) {
   child_labels <- match.arg(child_labels)
   if (is.null(labels_var)) {
     labels_var <- var
@@ -211,7 +224,9 @@ VarLevelSplit <- function(var,
     split_label_position = label_pos,
     content_extra_args = cextra_args,
     page_title_prefix = page_prefix,
-    child_section_div = section_div
+    child_section_div = section_div,
+    child_show_colcounts = show_colcounts,
+    child_colcount_format = colcount_format
   )
 }
 
@@ -229,6 +244,8 @@ AllSplit <- function(split_label = "",
                      cindent_mod = 0L,
                      cvar = "",
                      cextra_args = list(),
+                     show_colcounts = FALSE,
+                     colcount_format = NULL,
                      ...) {
   if (is.null(split_name)) {
     if (nzchar(split_label)) {
@@ -254,7 +271,9 @@ AllSplit <- function(split_label = "",
     split_label_position = "hidden",
     content_extra_args = cextra_args,
     page_title_prefix = NA_character_,
-    child_section_div = NA_character_
+    child_section_div = NA_character_,
+    child_show_colcounts = show_colcounts,
+    child_colcount_format = colcount_format
   )
 }
 
@@ -277,7 +296,9 @@ RootSplit <- function(split_label = "", cfun = NULL, cformat = NULL, cna_str = N
     content_var = cvar,
     split_label_position = "hidden",
     content_extra_args = cextra_args,
-    child_section_div = NA_character_
+    child_section_div = NA_character_,
+    child_show_colcounts = FALSE,
+    child_colcount_format = "(N=xx)"
   )
 }
 
@@ -321,7 +342,9 @@ ManualSplit <- function(levels, label, name = "manual",
     split_na_str = NA_character_,
     split_label_position = label_pos,
     page_title_prefix = page_prefix,
-    child_section_div = section_div
+    child_section_div = section_div,
+    child_show_colcounts = FALSE,
+    child_colcount_format = "(N=xx)"
   )
 }
 
@@ -394,7 +417,9 @@ MultiVarSplit <- function(vars,
                           label_pos = "visible",
                           split_fun = NULL,
                           page_prefix = NA_character_,
-                          section_div = NA_character_) {
+                          section_div = NA_character_,
+                          show_colcounts = FALSE,
+                          colcount_format = NULL) {
   check_ok_label(split_label)
   ## no topleft allowed
   label_pos <- match.arg(label_pos, label_pos_values[-3])
@@ -427,7 +452,9 @@ MultiVarSplit <- function(vars,
     content_extra_args = cextra_args,
     split_fun = split_fun,
     page_title_prefix = page_prefix,
-    child_section_div = section_div
+    child_section_div = section_div,
+    child_show_colcounts = show_colcounts,
+    child_colcount_format = colcount_format
   )
 }
 
@@ -480,7 +507,9 @@ make_static_cut_split <- function(var,
                                   label_pos = "visible",
                                   cumulative = FALSE,
                                   page_prefix = NA_character_,
-                                  section_div = NA_character_) {
+                                  section_div = NA_character_,
+                                  show_colcounts = FALSE,
+                                  colcount_format = NULL) {
   cls <- if (cumulative) "CumulativeCutSplit" else "VarStaticCutSplit"
   check_ok_label(split_label)
 
@@ -517,7 +546,9 @@ make_static_cut_split <- function(var,
     split_label_position = label_pos,
     content_extra_args = cextra_args,
     page_title_prefix = page_prefix,
-    child_section_div = section_div
+    child_section_div = section_div,
+    child_show_colcounts = show_colcounts,
+    child_colcount_format = colcount_format
   )
 }
 
@@ -564,7 +595,9 @@ VarDynCutSplit <- function(var,
                            cextra_args = list(),
                            label_pos = "visible",
                            page_prefix = NA_character_,
-                           section_div = NA_character_) {
+                           section_div = NA_character_,
+                           show_colcounts = FALSE,
+                           colcount_format = NULL) {
   check_ok_label(split_label)
   label_pos <- match.arg(label_pos, label_pos_values)
   child_labels <- match.arg(child_labels)
@@ -588,7 +621,9 @@ VarDynCutSplit <- function(var,
     split_label_position = label_pos,
     content_extra_args = cextra_args,
     page_title_prefix = page_prefix,
-    child_section_div = section_div
+    child_section_div = section_div,
+    child_show_colcounts = show_colcounts,
+    child_colcount_format = colcount_format
   )
 }
 
@@ -664,7 +699,9 @@ AnalyzeVarSplit <- function(var,
     var_label_position = label_pos,
     content_var = cvar,
     page_title_prefix = NA_character_,
-    child_section_div = section_div
+    child_section_div = section_div,
+    child_show_colcounts = FALSE,
+    child_colcount_format = NA_character_
   ) ## no content_extra_args
 }
 
@@ -708,7 +745,9 @@ AnalyzeColVarSplit <- function(afun,
     var_label_position = label_pos,
     content_var = cvar,
     page_title_prefix = NA_character_,
-    child_section_div = section_div
+    child_section_div = section_div,
+    child_show_colcounts = FALSE,
+    child_colcount_format = NA_character_
   ) ## no content_extra_args
 }
 
@@ -902,7 +941,9 @@ VarLevWBaselineSplit <- function(var,
                                  split_na_str = NA_character_,
                                  valorder = NULL,
                                  split_name = var,
-                                 extra_args = list()) {
+                                 extra_args = list(),
+                                 show_colcounts = FALSE,
+                                 colcount_format = NULL) {
   check_ok_label(split_label)
   new("VarLevWBaselineSplit",
     payload = var,
@@ -928,7 +969,9 @@ VarLevWBaselineSplit <- function(var,
     content_var = cvar,
     ## so long as this is columnspace only
     page_title_prefix = NA_character_,
-    child_section_div = NA_character_
+    child_section_div = NA_character_,
+    child_show_colcounts = show_colcounts,
+    child_colcount_format = colcount_format
   )
 }
 
@@ -955,7 +998,7 @@ TreePos <- function(spls = list(),
                     svlabels = character(),
                     sub = NULL) {
   check_ok_label(svlabels, multi_ok = TRUE)
-  svals <- make_splvalue_vec(vals = svals)
+  svals <- make_splvalue_vec(vals = svals, subset_exprs = lapply(svals, value_expr))
   if (is.null(sub)) {
     if (length(spls) > 0) {
       sub <- make_pos_subset(
@@ -992,6 +1035,7 @@ make_child_pos <- function(parpos,
     svlabels = c(pos_splval_labels(parpos), newlab),
     sub = .combine_subset_exprs(
       pos_subset(parpos),
+      ## this will grab the value's custom subset expression if present
       make_subset_expr(newspl, nsplitval)
     )
   )
@@ -1057,11 +1101,15 @@ setClass("LayoutAxisTree",
   }
 )
 
+## this is only used for columns!!!!
 setClass("LayoutAxisLeaf",
   contains = "VLayoutLeaf", ## "VNodeInfo",
   representation(
     func = "function",
-    col_footnotes = "list"
+    display_columncounts = "logical",
+    columncount_format = "FormatSpec", # character",
+    col_footnotes = "list",
+    column_count = "integer"
   )
 )
 
@@ -1069,8 +1117,9 @@ setClass("LayoutColTree",
   contains = "LayoutAxisTree",
   representation(
     display_columncounts = "logical",
-    columncount_format = "character",
-    col_footnotes = "list"
+    columncount_format = "FormatSpec", # "character",
+    col_footnotes = "list",
+    column_count = "integer"
   )
 )
 
@@ -1082,9 +1131,10 @@ LayoutColTree <- function(lev = 0L,
                           spl = EmptyAllSplit,
                           tpos = TreePos(),
                           summary_function = NULL,
-                          disp_colcounts = FALSE,
-                          colcount_format = "(N=xx)",
-                          footnotes = list()) { ## ,
+                          disp_ccounts = FALSE,
+                          colcount_format = NULL,
+                          footnotes = list(),
+                          colcount) { ## ,
   ## sub = expression(TRUE),
   ## svar = NA_character_,
   ## slab = NA_character_) {
@@ -1105,23 +1155,27 @@ LayoutColTree <- function(lev = 0L,
     ## subset = sub,
     ## splitvar = svar,
     label = label,
-    display_columncounts = disp_colcounts,
+    display_columncounts = disp_ccounts,
     columncount_format = colcount_format,
-    col_footnotes = footnotes
+    col_footnotes = footnotes,
+    column_count = colcount
   )
 }
 
 LayoutColLeaf <- function(lev = 0L,
                           name = label,
                           label = "",
-                          tpos = TreePos()) {
+                          tpos = TreePos(),
+                          colcount,
+                          disp_ccounts = FALSE,
+                          colcount_format = NULL) {
   check_ok_label(label)
   new("LayoutColLeaf",
     level = lev, name = .chkname(name), label = label,
-    pos_in_tree = tpos ## ,
-    ## subset = sub#,
-    ## N_count = n,
-    ## splitvar = svar
+    pos_in_tree = tpos,
+    column_count = colcount,
+    display_columncounts = disp_ccounts,
+    columncount_format = colcount_format
   )
 }
 
@@ -1168,7 +1222,7 @@ setClass(
 #'
 #' @export
 #' @rdname cinfo
-InstantiatedColumnInfo <- function(treelyt = LayoutColTree(),
+InstantiatedColumnInfo <- function(treelyt = LayoutColTree(colcount = total_cnt),
                                    csubs = list(expression(TRUE)),
                                    extras = list(list()),
                                    cnts = NA_integer_,
@@ -1200,6 +1254,15 @@ InstantiatedColumnInfo <- function(treelyt = LayoutColTree(),
     )
   }
 
+  if (!is.na(dispcounts)) {
+    pths <- col_paths(treelyt)
+    for (path in pths) {
+      colcount_visible(treelyt, path) <- dispcounts
+    }
+  } else { ## na leaves the children as they are and dispcols goes to whether any of them are displayed for the leaves
+    dispcounts <- any(vapply(leaves, disp_ccounts, NA))
+  }
+
   new("InstantiatedColumnInfo",
     tree_layout = treelyt,
     subset_exprs = csubs,
@@ -1740,7 +1803,7 @@ setClass("PreDataColLayout",
   contains = "PreDataAxisLayout",
   representation(
     display_columncounts = "logical",
-    columncount_format = "character"
+    columncount_format = "FormatSpec" # "character"
   )
 )
 
@@ -1750,7 +1813,7 @@ PreDataColLayout <- function(x = SplitVector(),
                              rtsp = RootSplit(),
                              ...,
                              lst = list(x, ...),
-                             disp_colcounts = FALSE,
+                             disp_colcounts = NA,
                              colcount_format = "(N=xx)") {
   ret <- new("PreDataColLayout", lst,
     display_columncounts = disp_colcounts,
