@@ -46,7 +46,12 @@ setGeneric(
 
 #' @rdname int_methods
 setMethod("split_rows", "NULL", function(lyt, spl, pos, cmpnd_fun = AnalyzeMultiVars) {
-  .Deprecated(msg = "Initializing layouts via NULL is deprecated, please use basic_table() instead")
+  lifecycle::deprecate_warn(
+    when = "0.3.8",
+    what = I("split_rows(NULL)"),
+    with = "basic_table()",
+    details = "Initializing layouts via `NULL` is no longer supported."
+  )
   rl <- PreDataRowLayout(SplitVector(spl))
   cl <- PreDataColLayout()
   PreDataTableLayouts(rlayout = rl, clayout = cl)
@@ -208,10 +213,12 @@ setGeneric(
 
 #' @rdname int_methods
 setMethod("split_cols", "NULL", function(lyt, spl, pos) {
-  .Deprecated(msg = paste(
-    "Initializing layouts via NULL is deprecated,",
-    "please use basic_table() instead"
-  ))
+  lifecycle::deprecate_warn(
+    when = "0.3.8",
+    what = I("split_cols(NULL)"),
+    with = "basic_table()",
+    details = "Initializing layouts via `NULL` is no longer supported."
+  )
   cl <- PreDataColLayout(SplitVector(spl))
   rl <- PreDataRowLayout()
   PreDataTableLayouts(rlayout = rl, clayout = cl)
@@ -357,7 +364,9 @@ split_cols_by <- function(lyt,
                           nested = TRUE,
                           child_labels = c("default", "visible", "hidden"),
                           extra_args = list(),
-                          ref_group = NULL) { ## ,
+                          ref_group = NULL,
+                          show_colcounts = FALSE,
+                          colcount_format = NULL) { ## ,
   if (is.null(ref_group)) {
     spl <- VarLevelSplit(
       var = var,
@@ -366,7 +375,9 @@ split_cols_by <- function(lyt,
       split_format = format,
       child_labels = child_labels,
       split_fun = split_fun,
-      extra_args = extra_args
+      extra_args = extra_args,
+      show_colcounts = show_colcounts,
+      colcount_format = colcount_format
     )
   } else {
     spl <- VarLevWBaselineSplit(
@@ -375,7 +386,9 @@ split_cols_by <- function(lyt,
       split_label = split_label,
       split_fun = split_fun,
       labels_var = labels_var,
-      split_format = format
+      split_format = format,
+      show_colcounts = show_colcounts,
+      colcount_format = colcount_format
     )
   }
   pos <- next_cpos(lyt, nested)
@@ -569,13 +582,18 @@ split_cols_by_multivar <- function(lyt,
                                    varlabels = vars,
                                    varnames = NULL,
                                    nested = TRUE,
-                                   extra_args = list()) {
+                                   extra_args = list(),
+                                   ## for completeness even though it doesn't make sense
+                                   show_colcounts = FALSE,
+                                   colcount_format = NULL) {
   spl <- MultiVarSplit(
     vars = vars, split_label = "",
     varlabels = varlabels,
     varnames = varnames,
     split_fun = split_fun,
-    extra_args = extra_args
+    extra_args = extra_args,
+    show_colcounts = show_colcounts,
+    colcount_format = colcount_format
   )
   pos <- next_cpos(lyt, nested)
   split_cols(lyt, spl, pos)
@@ -731,13 +749,17 @@ split_cols_by_cuts <- function(lyt, var, cuts,
                                cutlabels = NULL,
                                split_label = var,
                                nested = TRUE,
-                               cumulative = FALSE) {
+                               cumulative = FALSE,
+                               show_colcounts = FALSE,
+                               colcount_format = NULL) {
   spl <- make_static_cut_split(
     var = var,
     split_label = split_label,
     cuts = cuts,
     cutlabels = cutlabels,
-    cumulative = cumulative
+    cumulative = cumulative,
+    show_colcounts = show_colcounts,
+    colcount_format = colcount_format
   )
   ## if(cumulative)
   ##     spl = as(spl, "CumulativeCutSplit")
@@ -781,13 +803,17 @@ split_cols_by_cutfun <- function(lyt, var,
                                  split_label = var,
                                  nested = TRUE,
                                  extra_args = list(),
-                                 cumulative = FALSE) {
+                                 cumulative = FALSE,
+                                 show_colcounts = FALSE,
+                                 colcount_format = NULL) {
   spl <- VarDynCutSplit(var, split_label,
     cutfun = cutfun,
     cutlabelfun = cutlabelfun,
     extra_args = extra_args,
     cumulative = cumulative,
-    label_pos = "hidden"
+    label_pos = "hidden",
+    show_colcounts = show_colcounts,
+    colcount_format = colcount_format
   )
   pos <- next_cpos(lyt, nested)
   split_cols(lyt, spl, pos)
@@ -798,7 +824,9 @@ split_cols_by_cutfun <- function(lyt, var,
 split_cols_by_quartiles <- function(lyt, var, split_label = var,
                                     nested = TRUE,
                                     extra_args = list(),
-                                    cumulative = FALSE) {
+                                    cumulative = FALSE,
+                                    show_colcounts = FALSE,
+                                    colcount_format = NULL) {
   split_cols_by_cutfun(
     lyt = lyt,
     var = var,
@@ -814,7 +842,9 @@ split_cols_by_quartiles <- function(lyt, var, split_label = var,
     },
     nested = nested,
     extra_args = extra_args,
-    cumulative = cumulative
+    cumulative = cumulative,
+    show_colcounts = show_colcounts,
+    colcount_format = colcount_format
   )
   ## spl = VarDynCutSplit(var, split_label, cutfun = qtile_cuts,
   ##                      cutlabelfun = function(x) c("[min, Q1]",
@@ -1800,6 +1830,7 @@ setMethod(
 #' @param ... one or more vectors of levels to appear in the column space. If more than one set of levels is given,
 #'   the values of the second are nested within each value of the first, and so on.
 #' @param .lst (`list`)\cr a list of sets of levels, by default populated via `list(...)`.
+#' @param ccount_format (`FormatSpec`)\cr the format to use when counts are displayed.
 #'
 #' @return An `InstantiatedColumnInfo` object, suitable for declaring the column structure for a manually constructed
 #'   table.
@@ -1824,7 +1855,7 @@ setMethod(
 #'
 #' @author Gabriel Becker
 #' @export
-manual_cols <- function(..., .lst = list(...)) {
+manual_cols <- function(..., .lst = list(...), ccount_format = NULL) {
   if (is.null(names(.lst))) {
     names(.lst) <- paste("colsplit", seq_along(.lst))
   }
@@ -1833,10 +1864,78 @@ manual_cols <- function(..., .lst = list(...)) {
     levels = .lst,
     label = names(.lst)
   ))
-  ctree <- splitvec_to_coltree(data.frame(), splvec = splvec, pos = TreePos())
-  InstantiatedColumnInfo(treelyt = ctree)
+  ctree <- splitvec_to_coltree(data.frame(), splvec = splvec, pos = TreePos(), global_cc_format = ccount_format)
+
+  ret <- InstantiatedColumnInfo(treelyt = ctree)
+  rm_all_colcounts(ret)
 }
 
+
+#' Set all column counts at all levels of nesting to NA
+#'
+#' @inheritParams gen_args
+#'
+#' @return `obj` with all column counts reset to missing
+#'
+#' @export
+#' @examples
+#' lyt <- basic_table() %>%
+#'   split_cols_by("ARM") %>%
+#'   split_cols_by("SEX") %>%
+#'   analyze("AGE")
+#' tbl <- build_table(lyt, ex_adsl)
+#'
+#' # before
+#' col_counts(tbl)
+#' tbl <- rm_all_colcounts(tbl)
+#' col_counts(tbl)
+setGeneric("rm_all_colcounts", function(obj) standardGeneric("rm_all_colcounts"))
+
+#' @rdname rm_all_colcounts
+#' @export
+setMethod(
+  "rm_all_colcounts", "VTableTree",
+  function(obj) {
+    cinfo <- col_info(obj)
+    cinfo <- rm_all_colcounts(cinfo)
+    col_info(obj) <- cinfo
+    obj
+  }
+)
+
+#' @rdname rm_all_colcounts
+#' @export
+setMethod(
+  "rm_all_colcounts", "InstantiatedColumnInfo",
+  function(obj) {
+    ctree <- coltree(obj)
+    ctree <- rm_all_colcounts(ctree)
+    coltree(obj) <- ctree
+    obj
+  }
+)
+
+#' @rdname rm_all_colcounts
+#' @export
+setMethod(
+  "rm_all_colcounts", "LayoutColTree",
+  function(obj) {
+    obj@column_count <- NA_integer_
+    tree_children(obj) <- lapply(tree_children(obj), rm_all_colcounts)
+    obj
+  }
+)
+
+#' @rdname rm_all_colcounts
+#' @export
+setMethod(
+  "rm_all_colcounts", "LayoutColLeaf",
+  function(obj) {
+    obj@column_count <- NA_integer_
+    obj
+  }
+)
+
 #' Returns a function that coerces the return values of a function to a list
 #'
 #' @param f (`function`)\cr the function to wrap.
@@ -1898,10 +1997,15 @@ list_wrap_df <- function(f) {
 #' Every layout must start with a basic table.
 #'
 #' @inheritParams constr_args
-#' @param show_colcounts (`flag`)\cr whether column counts should be displayed in the resulting table when this
-#'   layout is applied to data.
+#' @param show_colcounts (`logical(1)`)\cr Indicates whether the lowest level of
+#'   applied to data. `NA`, the default, indicates that the `show_colcounts`
+#'   argument(s) passed to the relevant calls to `split_cols_by*`
+#'   functions. Non-missing values will override the behavior specified in
+#'   column splitting layout instructions which create the lowest level, or
+#'   leaf, columns.
 #' @param colcount_format (`string`)\cr format for use when displaying the column counts. Must be 1d, or 2d
-#'   where one component is a percent. See Details below.
+#'   where one component is a percent. This will also apply to any displayed higher
+#'   level column counts where an explicit format was not specified. Defaults to `"(N=xx)"`. See Details below.
 #' @param top_level_section_div (`character(1)`)\cr if assigned a single character, the first (top level) split
 #'   or division of the table will be highlighted by a line made of that character. See [section_div] for more
 #'   information.
@@ -1921,7 +2025,7 @@ list_wrap_df <- function(f) {
 #'   strange results, such as that individual arm columns and a combined "all patients" column all list "100%" as
 #'   their percentage, even though the individual arm columns represent strict subsets of the "all patients" column.
 #'
-#' - Note that subtitles ([subtitles()]) and footers ([main_footer()] and [prov_footer()]) that span more than one
+#' - Note that subtitles ([formatters::subtitles()]) and footers ([formatters::main_footer()] and [formatters::prov_footer()]) that span more than one
 #'   line can be supplied as a character vector to maintain indentation on multiple lines.
 #'
 #' @examples
@@ -1957,7 +2061,7 @@ basic_table <- function(title = "",
                         subtitles = character(),
                         main_footer = character(),
                         prov_footer = character(),
-                        show_colcounts = FALSE,
+                        show_colcounts = NA, # FALSE,
                         colcount_format = "(N=xx)",
                         header_section_div = NA_character_,
                         top_level_section_div = NA_character_,
@@ -1978,9 +2082,13 @@ basic_table <- function(title = "",
     top_level_section_div = top_level_section_div,
     table_inset = as.integer(inset)
   )
-  if (show_colcounts) {
-    ret <- add_colcounts(ret, format = colcount_format)
-  }
+
+  ## unconditional now, NA case is handled in cinfo construction
+  disp_ccounts(ret) <- show_colcounts
+  colcount_format(ret) <- colcount_format
+  ## if (isTRUE(show_colcounts)) {
+  ##   ret <- add_colcounts(ret, format = colcount_format)
+  ## }
   ret
 }
 
